Enumeration
AravisGcDisplayNotation
since: 0.8.0
Description [src]
Number display notations for showing numbers in user interfaces.
Available since: 0.8.0
Members
ARV_GC_DISPLAY_NOTATION_UNDEFINED-
Undefined number notation.
- Value:
-1 - Nickname:
undefined - Available since: 0.8.0
- Value:
ARV_GC_DISPLAY_NOTATION_AUTOMATIC-
Automatically detect whether to use fixed or scientific number notation.
- Value:
0 - Nickname:
automatic - Available since: 0.8.0
- Value:
ARV_GC_DISPLAY_NOTATION_FIXED-
Used fixed (i.e. decimal) notation for displaying numbers.
- Value:
1 - Nickname:
fixed - Available since: 0.8.0
- Value:
ARV_GC_DISPLAY_NOTATION_SCIENTIFIC-
Use scientific notation for displaying numbers.
- Value:
2 - Nickname:
scientific - Available since: 0.8.0
- Value: